==> mx-menu-editor_19.5.tar.xz: mx-menu-editor-19.5/translations/mx-menu-editor_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorijos</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Pridėti kategoriją</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Ištrinti kategoriją</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Įrašyti pakeitimus</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Išeiti iš dialogo</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Komentaras:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Piktograma:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Nustatyti piktogramą</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Vykdyti terminale</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Pridėti tinkintą programą</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Nepavyko įrašyti failo</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Įrašyti pakeitimus?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Ar norite įrašyti savo taisymus?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>MX Menu Editor</source>
        <translation>MX meniu redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Išplėstinis redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorijos ir programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Pridėti tinkintą programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Parametrai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Vykdyti terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Paslėpti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Spartusis redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Komentaras:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Atkurti pradinį elementą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Piktograma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Change icon</source>
        <translation>Pakeisti piktogramą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategorijos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Įrašyti pakeitimus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Select executable file</source>
        <translation>Pasirinkite vykdomąjį failą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Paveikslo failai (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Choose category</source>
        <translation>Pasirinkite kategoriją</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="845"/>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Could not save the file</source>
        <translation>Nepavyko įrašyti failo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>About MX Menu Editor</source>
        <translation>Apie MX meniu redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programa, skirta Xfce meniu taisymui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save changes?</source>
        <translation>Įrašyti pakeitimus?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Do you want to save your edits?</source>
        <translation>Ar norite įrašyti savo taisymus?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Privalote paleisti šią programą kaip normalus naudotojas.</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_21.7.01.tar.xz: mx-menu-editor-21.7.01/translations/mx-menu-editor_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorijos</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Pridėti kategoriją</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Ištrinti kategoriją</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Įrašyti pakeitimus</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Išeiti iš dialogo</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Komentaras:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Piktograma:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="111"/>
        <source>Set icon</source>
        <translation>Nustatyti piktogramą</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Vykdyti terminale</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="35"/>
        <source>Add Custom Application</source>
        <translation>Pridėti tinkintą programą</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Could not save the file</source>
        <translation>Nepavyko įrašyti failo</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Save changes?</source>
        <translation>Įrašyti pakeitimus?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Do you want to save your edits?</source>
        <translation>Ar norite įrašyti savo taisymus?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Įrašyti</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>MX Menu Editor</source>
        <translation>MX meniu redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Išplėstinis redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorijos ir programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Pridėti tinkintą programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Parametrai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Vykdyti terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Paslėpti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Spartusis redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Komentaras:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Atkurti pradinį elementą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Pasirinkti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Piktograma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Change icon</source>
        <translation>Pakeisti piktogramą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategorijos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Įrašyti pakeitimus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Select executable file</source>
        <translation>Pasirinkite vykdomąjį failą</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation type="vanished">Paveikslo failai (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Choose category</source>
        <translation>Pasirinkite kategoriją</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Could not save the file</source>
        <translation>Nepavyko įrašyti failo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>About MX Menu Editor</source>
        <translation>Apie MX meniu redaktorius</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Program for editing Xfce menu</source>
        <translation>Programa, skirta Xfce meniu taisymui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>Save changes?</source>
        <translation>Įrašyti pakeitimus?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Do you want to save your edits?</source>
        <translation>Ar norite įrašyti savo taisymus?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Privalote paleisti šią programą kaip normalus naudotojas.</translation>
    </message>
</context>
</TS>
